@@ -944,6 +944,7 @@ exports = ['ADDEVENT',
  'SCANCODE_X',
  'SCANCODE_Y',
  'SCANCODE_Z',
+ 'SDLError',
  'SWSURFACE',
  'SYSTEM_CURSOR_ARROW',
  'SYSTEM_CURSOR_CROSSHAIR',
@@ -1550,4 +1551,4 @@ ns_dict['image'] = '_sdl_image.renamed'
 ns_dict['mixer'] = '_sdl_mixer.renamed'
 ns_dict['ttf'] = '_sdl_ttf.renamed'
 
-apipkg.initpkg(__name__, ns_dict)
+apipkg.initpkg(__name__, ns_dict, {'__all__':exports})
